# eric7.PdfViewer

Package implementing a simple PDF viewer tool.

### Modules

PdfGoToDialog | Module implementing a dialog to enter a PDF page number to jump to.
PdfInfoWidget | Module implementing an info widget showing data of a PDF document.
PdfPageSelector | Module implementing a widget to select a PDF page to be shown.
PdfSearchWidget | Module implementing a Search widget.
PdfToCWidget | Module implementing a Table of Contents viewer widget.
PdfView | Module implementing a specialized PDF view class.
PdfViewerWindow | Module implementing the PDF viewer main window.
PdfZoomSelector | Module implementing a widget to select a PDF zoom factor.